<p align="center">
  <img src="tornadmin/static/tornadmin/img/splash.png" width="180" alt="Tornadmin icon">
</p>

<p align="center">
    Admin site for Tornado web server.
</p>

<p align="center">
    <a href="http://tornadmin.rtfd.io">Documentation</a> &bull;
    <code>Python &gt;= 3.7</code>
</p>

<p align="center">
    <strong>/!\ Work in progress</strong>
</p>

## Introduction

Tornadmin is an admin site generation framework for Tornado web server. It is inspired a little by Django-Admin and a lot by Flask-Admin.

## Supported database ORMs

 - [x] Tortoise ORM
 - [ ] SQLAlchemy

## Install

Install via pip:

```sh
$ pip install tornadmin
```

## Documentation

Quickstart and usage docs can be found at [https://tornadmin.rtfd.io](http://tornadmin.rtfd.io).

## License

[BSD-3-Clause](LICENSE.txt)

---

If you've found this library useful, and if you wish to support me you can:

<a href="https://www.buymeacoffee.com/bhch">
    <img src="https://www.buymeacoffee.com/assets/img/guidelines/download-assets-sm-2.svg" width="170">
</a>
